##  Call-to-Action with Regards to Use Cases
Important features:
  * Welcome message to introduce the use case, clarify the use case approach and eventually actions you are asking for from users
  * Include a To Do Panel, so users are being led directly to their open tasks
  * Find fact sheet charts that answer the key questions/ address the key goals of the use case, eg.
    * Save 20% of application cost by Rationalization
    * Reduce Technology Risk
  * Show use case specific filtered and saved reports
  * You might also want to include Metrics if applicable to show use cases development over time


### Example: Data Completeness and Inventory Metrics
  * Fact sheet chart to show distribution of tag group "FormalCorrectness"
  * IT components with missing information (filtered report for “na”)
  * Metrics: Number of applications
  * Metrics: Number of IT components


**Note**
In this example the fact sheet chart is making use of the tag group “FormalCorrectness” with 4 Tags (Completed, New and not yet completed, Not yet completed, Not relevant).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f023a7a441014842daca34425f453_LowRes.png)
### Example: Application Rationalization
  * fact sheet chart to show the distribution of tag group "TIME Model"
  * application TIME assessment in application portfolio report
  * application roadmap


**Note**
In this example the fact sheet chart is making use of the tag group “TIME Model” with 4 Tags (Tolerate, Invest, Migrate, Eliminate).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757696a7a441014a6c1f38c55234a5a_LowRes.png)
### Example: Technology Risk Management
  * application landscape clustered by TIME Model with technology risk view to see if the TIME assessment adequately addresses your risks
  * IT component landscape with providers criticality/ quality
  * IT component landscape with tech category resource classification
  * IT component landscape with technical fit view
  * IT component matrix with lifecycle information
  * provider cost report
  * IT component roadmap


**Note**
In this example the fact sheet chart is making use of the tag group “TIME Model” with 4 Tags (Tolerate, Invest, Migrate, Eliminate).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27524c757a4410149ccfab2ab5b2655a_LowRes.png)
### Example: Cloud Transformation
  * Fact sheet chart on applications cloud transformation
  * Fact sheet chart on on-premise applications, regarding the TIME model
  * Reports application landscape with cost view
  * Report on cloud migration project cost
  * Report on current architecture 2020 versus target architecture in 2023


**Note**
In this example the fact sheet chart is making use of the tag group “TIME Model” with 4 Tags (Tolerate, Invest, Migrate, Eliminate) and the tag group “Cloud Transformation” with 4 Tags (On-Premise, Public Cloud, Hybrid Cloud, Private Cloud).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750d0427a441014b580c624dccbb43c_LowRes.png)
### Example: KPIs for EA Status
  * Fact sheet chart on applications with components reuse by tag group
  * Fact sheet chart on projects reviewed by internal governance
  * Fact sheet chart on project landscape by tag group of projects strategic classification
  * You might also want to include Metrics if applicable to show your KPIs development over time


**Note**
In this example the fact sheet chart is making use of the tag group "Components Reuse", tag group "Reviewed", tag group "Project Classification".
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27553a9f7a441014bad2b33e1d8a72bc_LowRes.png)
